@@ -8,7 +8,8 @@ from typing import List
 
 from chainlib.eth.address import is_address
 
-from cic_helper.constants import CSV_HEADER, CSV_Column
+from cic_helper.constants import (CHAIN_SPEC, CSV_HEADER, RPC_PROVIDER,
+                                  CSV_Column)
 
 log = logging.getLogger(__name__)
 
@@ -51,13 +52,17 @@ class Person:
                     f"Failed to get address for {self.phone_number}\n STDOUT: {result.stdout}\n STDERR:{result.stderr}")
         return self.user_address
 
-    def get_balance(self, tokenAddress: str):
-        result = subprocess.run(['erc20-balance', '--fee-limit', '1000000000', '-p', 'http://127.0.0.1:8545',
-                                 '-i', 'evm:kitabu:6060:sarafu', '-u', '-e', tokenAddress, self.user_address], capture_output=True, text=True)
+    def get_balance(self, contract_address: str, fee_limit=800000):
+        self.contract_address = contract_address if contract_address else self.contract_address
+        result = subprocess.run(['erc20-balance', '--fee-limit', str(fee_limit), '-p', RPC_PROVIDER,
+                                 '-i', CHAIN_SPEC, '-u', '-e', self.contract_address, self.user_address], capture_output=True, text=True)
         try:
             self.current_balance = float(result.stdout.strip())
+            log.info(f"{self.phone_number} - {self.current_balance}")
         except Exception as e:
             self.current_balance = None
+            log.error(
+                f"Failed to get balance for: {self.phone_number} ({self.user_address})")
             pass
         return self.current_balance
 
@@ -78,20 +83,27 @@ class Person:
         else:
             return None
 
-    def transfer(self, checkBalance=True):
-        if(checkBalance and self.has_corrent_amount()):
-            print(f"Skipping {self.phone_number} as balance is within range")
-            print(
+    def send(self, contract_address, signer_keyfile, fee_limit=800000, force=False):
+        self.contract_address = contract_address
+        if(not force and self.has_corrent_amount()):
+            log.info(
+                f"Skipping {self.phone_number} as balance is within range")
+            log.info(
                 f"  Network: {self.current_balance}, Requested: {self.send_amount}")
             return
         else:
-            print(
-                f"  Sending {self.send_amount} to {self.phone_number} ({self.user_address}) from {self.contract_address}")
-            # result = subprocess.run([
-            #     "erc20-transfer", "-p", "https://rpc.kitabu.grassecon.org", "-i", "evm:kitabu:5050:sarafu", "-u", "-e", tokenAddress, "--fee-limit", "10000000", "-y", "/home/sarafu/keystore/wor-deployer-wallet-keyfile", "-a", self.address, "10000000000", "-s"], capture_output=True,
-            #     text=True)
-            # txHash = result.stdout
-            print(f"  Sent: ")
+            log.info(
+                f"  Sending {self.send_amount} to {self.phone_number} ({self.user_address})")
+            cmd = ["erc20-transfer", "-p", RPC_PROVIDER, "-i", CHAIN_SPEC, "-u", "-e", contract_address, "--fee-limit",
+                   str(fee_limit), "-y", signer_keyfile, "-a", self.user_address, str(self.send_amount), "-s"]
+            log.debug("> " + " ".join(cmd))
+            try:
+                result = subprocess.run(cmd, capture_output=True,
+                                        text=True)
+                log.info("Stdout: ", result.stdout)
+                log.info("Error: ", result.stderr)
+            except Exception as e:
+                log.error(e)
 
     def to_row(self) -> List[str]:
         return [self.phone_number, self.user_address, self.contract_address, self.current_balance, self.send_amount, self.timestamp]
